v3.0.0
======

Features
--------

- Require Python 3.8 or later.


Deprecations and Removals
-------------------------

- Removed all functionality.


2.0
===

Switch to `pkgutil namespace technique
<https://packaging.python.org/guides/packaging-namespace-packages/#pkgutil-style-namespace-packages>`_
for the ``jaraco`` namespace.

1.3.2
=====

Refresh build with updated skeleton.

1.3.1
=====

Use absolute import to avoid attempting to import
jaraco.tempora from jaraco.util.

1.3
===

All functionality moved to the `tempora
<https://pypi.org/project/tempora>`_ project.

Configured automatic deployment (for the last release).

1.2
===

Move hosting to Github.

Fix issue in tests with version detection.

1.1.3
=====

Re-release of 1.1.2 fixing distribution.

1.1
===

Specified license.

1.0
===

Extracted `timing` module from jaraco.util 10.1.
